@@ -1,9 +1,9 @@
-module Omniauth
+module OmniAuth
   module Azure
     module Activedirectory
       module V2
-        VERSION = "1.0.0"
-        DATE    = "2020-09-25"
+        VERSION = "2.4.0"
+        DATE    = "2024-10-17"
       end
     end
   end
